@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,24 +20,23 @@
 #define SIEVEACTIONABSTRACTFLAGS_H
 
 #include "sieveaction.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionAbstractFlags : public SieveAction
 {
     Q_OBJECT
 public:
     SieveActionAbstractFlags(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent = nullptr);
 
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    QString code(QWidget *) const override;
+    QStringList needRequires(QWidget *parent) const override;
 
     virtual QString flagsCode() const = 0;
 
-    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
+    bool needCheckIfServerHasCapability() const override;
 
-    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
+    QString serverNeedsCapability() const override;
 };
 }
 
