@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,18 +20,20 @@
 #define SIEVEACTIONDELETEHEADER_H
 
 #include "sieveactionabstracteditheader.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionDeleteHeader : public SieveActionAbstractEditHeader
 {
     Q_OBJECT
 public:
     explicit SieveActionDeleteHeader(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString code(QWidget *w) const Q_DECL_OVERRIDE;
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QString code(QWidget *w) const override;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    QString help() const override;
+    QUrl href() const override;
+    QStringList needRequires(QWidget *parent) const override;
+private:
+    bool parseValue(QXmlStreamReader &element, QWidget *w, QString &error, bool isNegative);
 };
 }
 
