@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@
 #include <QLineEdit>
 
 #include <QLabel>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 #include <QGridLayout>
 
@@ -69,45 +69,43 @@ QWidget *SieveActionEnclose::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionEnclose::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionEnclose::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("tag")) {
-                const QString tagValue = e.text();
-                if (tagValue == QLatin1String("headers")) {
-                    const QString strValue = AutoCreateScriptUtil::strValue(node);
-                    if (!strValue.isEmpty()) {
-                        QLineEdit *subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
-                        subject->setText(strValue);
-                    }
-                } else if (tagValue == QLatin1String("subject")) {
-                    const QString strValue = AutoCreateScriptUtil::strValue(node);
-                    if (!strValue.isEmpty()) {
-                        QLineEdit *headers = w->findChild<QLineEdit *>(QStringLiteral("headers"));
-                        headers->setText(strValue);
-                    }
-                } else {
-                    unknowTagValue(tagValue, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveActionEnclose::setParamWidgetValue unknown tag value:" << tagValue;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("tag")) {
+            const QString tagValue = element.readElementText();
+            if (tagValue == QLatin1String("headers")) {
+                const QString strValue = AutoCreateScriptUtil::strValue(element);
+                if (!strValue.isEmpty()) {
+                    QLineEdit *subject = w->findChild<QLineEdit *>(QStringLiteral("headers"));
+                    subject->setText(strValue);
+                }
+            } else if (tagValue == QLatin1String("subject")) {
+                const QString strValue = AutoCreateScriptUtil::strValue(element);
+                if (!strValue.isEmpty()) {
+                    QLineEdit *headers = w->findChild<QLineEdit *>(QStringLiteral("subject"));
+                    headers->setText(strValue);
                 }
-            } else if (tagName == QLatin1String("str")) {
-                MultiLineEdit *edit = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
-                edit->setPlainText(e.text());
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
             } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveActionEnclose::setParamWidgetValue unknown tagName " << tagName;
+                unknowTagValue(tagValue, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionEnclose::setParamWidgetValue unknown tag value:" << tagValue;
             }
+        } else if (tagName == QLatin1String("str")) {
+            MultiLineEdit *edit = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
+            edit->setPlainText(element.readElementText());
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            element.skipCurrentElement();
+            //implement in the future ?
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionEnclose::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
@@ -137,7 +135,7 @@ QString SieveActionEnclose::code(QWidget *w) const
     return result;
 }
 
-QStringList SieveActionEnclose::needRequires(QWidget */*parent*/) const
+QStringList SieveActionEnclose::needRequires(QWidget * /*parent*/) const
 {
     return QStringList() << QStringLiteral("enclose");
 }
@@ -161,4 +159,3 @@ QUrl SieveActionEnclose::href() const
 {
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
-
