@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,19 +20,18 @@
 #define SIEVEACTIONRETURN_H
 
 #include "sieveaction.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionReturn : public SieveAction
 {
     Q_OBJECT
 public:
     explicit SieveActionReturn(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString help() const Q_DECL_OVERRIDE;
-    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
-    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
-    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QString help() const override;
+    QStringList needRequires(QWidget *parent) const override;
+    bool needCheckIfServerHasCapability() const override;
+    QString serverNeedsCapability() const override;
+    QString code(QWidget *) const override;
+    QUrl href() const override;
 };
 }
 
