@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -122,7 +122,7 @@ void SieveActionWidget::initWidget()
     int index = 0;
     QStringList listCapabilities = mSieveGraphicalModeWidget->sieveCapabilities();
     //imapflags was old name of imap4flags but still used.
-    if (listCapabilities.contains(QStringLiteral("imap4flags"))) {
+    if (listCapabilities.contains(QLatin1String("imap4flags"))) {
         listCapabilities.append(QStringLiteral("imapflags"));
     }
     for (index = 0, it = list.constBegin(); it != end; ++it, ++index) {
@@ -396,8 +396,8 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
     if (onlyActions) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("action")) {
-            if (element.attributes().hasAttribute(QStringLiteral("name"))) {
-                const QString actionName = element.attributes().value(QStringLiteral("name")).toString();
+            if (element.attributes().hasAttribute(QLatin1String("name"))) {
+                const QString actionName = element.attributes().value(QLatin1String("name")).toString();
                 SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                 if (w->isConfigurated()) {
                     addWidgetAfterThisWidget(widgets().constLast());
@@ -420,8 +420,8 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
         while (element.readNextStartElement()) {
             const QStringRef tagName = element.name();
             if (tagName == QLatin1String("action") || tagName == QLatin1String("control") /*for break action*/) {
-                if (element.attributes().hasAttribute(QStringLiteral("name"))) {
-                    const QString actionName = element.attributes().value(QStringLiteral("name")).toString();
+                if (element.attributes().hasAttribute(QLatin1String("name"))) {
+                    const QString actionName = element.attributes().value(QLatin1String("name")).toString();
                     if (tagName == QLatin1String("control") && actionName == QLatin1String("if")) {
                         qCDebug(LIBKSIEVE_LOG) << "We found an loop if in a loop if. Not supported";
                         error += i18n("We detected a loop if in a loop if. It's not supported") + QLatin1Char('\n');
