@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,12 +21,10 @@
 
 #include <QList>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveCondition;
 class SieveEditorGraphicalModeWidget;
-namespace SieveConditionList
-{
+namespace SieveConditionList {
 QList<KSieveUi::SieveCondition *> conditionList(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget);
 }
 }
