@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -59,20 +59,18 @@ public:
 Q_SIGNALS:
     void valueChanged();
 
-private Q_SLOTS:
-    void slotDateTypeActivated(int);
-
 private:
+    void slotDateTypeActivated(int);
     SelectDateWidget::DateType dateTypeFromString(const QString &str);
     void initialize();
     QString dateType(DateType type) const;
     QString dateValue(DateType type) const;
-    KComboBox *mDateType;
-    QLineEdit *mDateLineEdit;
-    SieveDateSpinBox *mDateValue;
-    KDateComboBox *mDateEdit;
-    KTimeComboBox *mTimeEdit;
-    QStackedWidget *mStackWidget;
+    KComboBox *mDateType = nullptr;
+    QLineEdit *mDateLineEdit = nullptr;
+    SieveDateSpinBox *mDateValue = nullptr;
+    KDateComboBox *mDateEdit = nullptr;
+    KTimeComboBox *mTimeEdit = nullptr;
+    QStackedWidget *mStackWidget = nullptr;
 };
 }
 Q_DECLARE_METATYPE(KSieveUi::SelectDateWidget::DateType)
