@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,15 +34,13 @@ public:
 
     void setError(QString script, QString);
 
-private Q_SLOTS:
-    void slotSaveAs();
-
 private:
+    void slotSaveAs();
     void readConfig();
     void writeConfig();
 
 private:
-    KPIMTextEdit::RichTextEditorWidget *mTextEdit;
+    KPIMTextEdit::RichTextEditorWidget *mTextEdit = nullptr;
 };
 }
 #endif // SIEVESCRIPTPARSINGERRORDIALOG_H
