@@ -1,5 +1,5 @@
 /* Copyright (C) 2010 Torgny Nyblom <nyblom@kde.org>
- * Copyright (C) 2010-2017 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2010-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class QPushButton;
 class QMenu;
 class QLabel;
 namespace PimCommon {
-class LineEditWithCompleter;
+class LineEditWithCompleterNg;
 }
 namespace KSieveUi {
 class KSIEVEUI_EXPORT FindBarBase : public QWidget
@@ -35,7 +35,7 @@ class KSIEVEUI_EXPORT FindBarBase : public QWidget
     Q_OBJECT
 public:
     explicit FindBarBase(QWidget *parent = nullptr);
-    virtual ~FindBarBase();
+    ~FindBarBase() override;
 
     QString text() const;
     void setText(const QString &text);
@@ -64,20 +64,19 @@ Q_SIGNALS:
 protected Q_SLOTS:
     void caseSensitivityChanged(bool);
     void slotHighlightAllChanged(bool);
-    void slotClearSearch();
 
 protected:
     QString mNotFoundString;
     QString mPositiveBackground;
     QString mNegativeBackground;
     QString mLastSearchStr;
-    PimCommon::LineEditWithCompleter *mSearch;
-    QAction *mCaseSensitiveAct;
+    PimCommon::LineEditWithCompleterNg *mSearch = nullptr;
+    QAction *mCaseSensitiveAct = nullptr;
 
-    QPushButton *mFindPrevBtn;
-    QPushButton *mFindNextBtn;
-    QMenu *mOptionsMenu;
-    QLabel *mStatus;
+    QPushButton *mFindPrevBtn = nullptr;
+    QPushButton *mFindNextBtn = nullptr;
+    QMenu *mOptionsMenu = nullptr;
+    QLabel *mStatus = nullptr;
     void addToCompletion(const QString &text);
 };
 }
