@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,18 +20,17 @@
 
 #include <QWebEngineView>
 class QWebEngineDownloadItem;
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveEditorWebEngineView : public QWebEngineView
 {
     Q_OBJECT
 public:
     explicit SieveEditorWebEngineView(QWidget *parent = nullptr);
-    ~SieveEditorWebEngineView();
+    ~SieveEditorWebEngineView() override;
 
 protected:
-    void contextMenuEvent(QContextMenuEvent *ev) Q_DECL_OVERRIDE;
-    QWebEngineView *createWindow(QWebEnginePage::WebWindowType type) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *ev) override;
+    QWebEngineView *createWindow(QWebEnginePage::WebWindowType type) override;
 private:
     void downloadRequested(QWebEngineDownloadItem *);
 };
