@@ -77,9 +77,10 @@ Q_SIGNALS:
     void result(CheckKolabKep14SupportJob *, bool);
 
 private:
-    CheckKolabKep14SupportJobPrivate *d;
+    CheckKolabKep14SupportJobPrivate *const d;
 
-private Q_SLOTS:
+private:
+    Q_DISABLE_COPY(CheckKolabKep14SupportJob)
     void slotCheckKep14Support(KManageSieve::SieveJob *job, bool success, const QStringList &availableScripts, const QString &activeScript);
 };
 }
