@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -44,11 +44,10 @@ public:
 Q_SIGNALS:
     void finished(const QString &msg, bool success);
 
-private Q_SLOTS:
+private:
+    Q_DISABLE_COPY(CheckScriptJob)
     void slotPutCheckSyntaxResult(KManageSieve::SieveJob *job, bool success);
     void slotRestoreFile(KManageSieve::SieveJob *job, bool success);
-
-private:
     CheckScriptJobPrivate *const d;
 };
 }
