@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@ class SieveScriptDebuggerTextEdit : public KSieveUi::SieveTextEdit
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerTextEdit(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerTextEdit();
+    ~SieveScriptDebuggerTextEdit() override;
 
 protected:
     void addExtraMenuEntry(QMenu *menu, QPoint pos) override;
