@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -43,12 +43,14 @@ public:
 
 Q_SIGNALS:
     void scriptTextChanged();
+    void debugScriptButtonClicked();
+    void debugButtonEnabled(bool state);
 
 private:
     void checkSieveTestApplication();
-    QStackedWidget *mStackedWidget;
-    SieveScriptDebuggerFrontEndWidget *mSieveScriptFrontEnd;
-    QLabel *mSieveNoExistingFrontEnd;
+    QStackedWidget *mStackedWidget = nullptr;
+    SieveScriptDebuggerFrontEndWidget *mSieveScriptFrontEnd = nullptr;
+    QLabel *mSieveNoExistingFrontEnd = nullptr;
 };
 }
 #endif // SIEVESCRIPTDEBUGGERWIDGET_H
