@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,7 +21,6 @@
 #define AKONADIIMAPSETTINGINTERFACE_H
 
 #include "abstractakonadiimapsettinginterface.h"
-#include <QObject>
 #include <memory>
 class OrgKdeAkonadiImapSettingsInterface;
 namespace KSieveUi {
@@ -29,7 +28,7 @@ class AkonadiImapSettingInterface : public KSieveUi::AbstractAkonadiImapSettingI
 {
 public:
     AkonadiImapSettingInterface(std::unique_ptr<OrgKdeAkonadiImapSettingsInterface> &interface);
-    ~AkonadiImapSettingInterface();
+    ~AkonadiImapSettingInterface() override;
 
     bool sieveSupport() const override;
     bool sieveReuseConfig() const override;
