@@ -39,7 +39,6 @@
 #include <QString>
 #include <QStringList>
 #include <QTextCodec>
-#include <QDebug>
 
 #include <memory> // std::unique_ptr
 
@@ -172,7 +171,7 @@ static inline bool is8Bit(signed char ch)
 
 static QString removeCRLF(const QString &s)
 {
-    const bool CRLF = s.endsWith(QStringLiteral("\r\n"));
+    const bool CRLF = s.endsWith(QLatin1String("\r\n"));
     const bool LF = !CRLF && s.endsWith(QLatin1Char('\n'));
 
     const int e = CRLF ? 2 : LF ? 1 : 0;  // what to chop off at the end
@@ -182,7 +181,7 @@ static QString removeCRLF(const QString &s)
 
 static QString removeDotStuff(const QString &s)
 {
-    return s.startsWith(QStringLiteral("..")) ? s.mid(1) : s;
+    return s.startsWith(QLatin1String("..")) ? s.mid(1) : s;
 }
 
 namespace KSieve {
@@ -295,7 +294,7 @@ Lexer::Token Lexer::Impl::nextToken(QString &result)
             // and CRLF! That should be preserved somehow...
             return MultiLineString;
         }
-    // else fall through:
+        Q_FALLTHROUGH();
     default: // Identifier (first must not be 0-9, and can't (caught by Number above))
         if (!isIText(*mState.cursor)) {
             makeError(Error::IllegalCharacter);
@@ -689,7 +688,7 @@ bool Lexer::Impl::parseQuotedString(QString &result)
             if (atEnd()) {
                 break;
             }
-        // else fall through:
+            Q_FALLTHROUGH();
         default:
             if (!is8Bit(*mState.cursor)) {
                 result += QLatin1Char(*mState.cursor++);
